@@ -32,8 +32,10 @@ class PF_RINGInterface : public NetworkInterface {
  private:
   pfring *pfring_handle[PF_RING_MAX_SOCKETS];
   int num_pfring_handles;
+  u_int32_t dropped_packets;
 
   pfring_stat last_pfring_stat;
+  void updatePacketsStats();
   u_int32_t getNumDroppedPackets();
   pfring *pfringSocketInit(const char *name);
 
