@@ -108,6 +108,7 @@
 
 #define ZMQ_COMPATIBILITY_MSG_VERSION 1
 #define ZMQ_MSG_VERSION           2
+#define ZMQ_MSG_VERSION_TLV       3 /* not supported by this version */
 #define LOGIN_URL                 "/lua/login.lua"
 #define LOGOUT_URL                "/lua/logout.lua"
 #define CAPTIVE_PORTAL_URL        "/lua/captive_portal.lua"
@@ -133,9 +134,10 @@
 #define NO_UID                    ((u_int32_t)-1)
 #define NO_PID                    ((u_int32_t)-1)
 #define NO_NDPI_PROTOCOL          ((u_int)-1)
-#define NDPI_MIN_NUM_PACKETS      10
+#define NDPI_MIN_NUM_PACKETS      12
 #define GTP_U_V1_PORT             2152
 #define TZSP_PORT                 37008
+#define VXLAN_PORT                4789
 #define CAPWAP_DATA_PORT          5247
 #define MAX_NUM_INTERFACE_HOSTS   131072
 #define MAX_NUM_VIEW_INTERFACES   8
