@@ -98,11 +98,21 @@ for _key, _value in pairsByValues(vals, funct) do
 	    print ("  \"column_host_pool_name\" : \"" .. pool_names[value["host_pool_id"]].. "\", ")
 	 end
 
-	 print ("  \"column_group\"     : \"" .. value["group"] .. "\", ")
-	 print ("  \"column_edit\"      : \"<a href='#password_dialog' data-toggle='modal' onclick='return(reset_pwd_dialog(\\\"".. key.."\\\"));'><span class='label label-info'>Manage</span></a> ")
+local group_label
+
+if value["group"] == "administrator" then
+   group_label = i18n("manage_users.administrator")
+elseif value["group"] == "unprivileged" then
+   group_label = i18n("manage_users.non_privileged_user")
+else
+   group_label = value["group"]
+end
+
+	 print ("  \"column_group\"     : \"" .. group_label .. "\", ")
+	 print ("  \"column_edit\"      : \"<a href='#password_dialog' data-toggle='modal' onclick='return(reset_pwd_dialog(\\\"".. key.."\\\"));'><span class='label label-info'>" .. i18n("manage_users.manage") .. "</span></a> ")
 
   if(key ~= "admin") then
-	    print ("<a href='#delete_user_dialog' role='button' class='add-on' data-toggle='modal' id='delete_btn_" .. key .. "'><span class='label label-danger'>Delete</span></a><script> $('#delete_btn_" .. key .. "').on('mouseenter', function() { delete_user_alert.warning('Are you sure you want to delete " .. key .. "?'); $('#delete_dialog_username').val('" .. key .. "'); }); </script>")
+	    print ("<a href='#delete_user_dialog' role='button' class='add-on' data-toggle='modal' id='delete_btn_" .. key .. "'><span class='label label-danger'>" .. i18n("delete") .. "</span></a><script> $('#delete_btn_" .. key .. "').on('mouseenter', function() { delete_user_alert.warning('" .. i18n("manage_users.confirm_delete_user", {user=key}) .. "'); $('#delete_dialog_username').val('" .. key .. "'); }); </script>")
 	 end
 	 print ("\"}")
 	 num = num + 1
