@@ -98,6 +98,10 @@ if ifstats.stats and ifstats.stats_since_reset then
    end
 end
 
+-- refreshing traffic recording availability as one may have installed 
+-- n2disk while ntopng was running
+recording_utils.checkAvailable()
+
 local ext_interfaces = {}
 if recording_utils.isAvailable() and recording_utils.isSupportedZMQInterface(ifid) then
    ext_interfaces = recording_utils.getExtInterfaces(ifid)
@@ -246,15 +250,15 @@ if(isAdministrator() and areAlertsEnabled() and not ifstats.isView) then
 end
 
 if ts_utils.getDriverName() == "rrd" then
-if(ntop.isEnterprise()) then
+   if ntop.isEnterprise() or ntop.isnEdge() then
       if(page == "traffic_report") then
          print("\n<li class=\"active\"><a href=\"#\"><i class='fa fa-file-text report-icon'></i></a></li>\n")
       else
          print("\n<li><a href=\""..url.."&page=traffic_report\"><i class='fa fa-file-text report-icon'></i></a></li>")
       end
-elseif not have_nedge then
+   else
       print("\n<li><a href=\"#\" title=\""..i18n('enterpriseOnly').."\"><i class='fa fa-file-text report-icon'></i></A></li>\n")
-end
+   end
 end
 
 if(isAdministrator()) then
@@ -596,7 +600,7 @@ if(ifstats.zmqRecvStats ~= nil) then
 
       if storage_info.rrd ~= nil and storage_info.rrd > 0 then
         table.insert(storage_items, {
-          title = i18n("prefs.timeseries"),
+          title = i18n("if_stats_overview.rrd_timeseries"),
           value = storage_info.rrd,
           class = "primary",
         })
@@ -631,15 +635,17 @@ if(ifstats.zmqRecvStats ~= nil) then
         print("</td></tr>\n")
       end
    end
- 
-   if (isAdministrator() and ifstats.isView == false and ifstats.isDynamic == false) then
+
+   if (isAdministrator() and ifstats.isView == false and ifstats.isDynamic == false and interface.isPacketInterface()) then  
       print("<tr><th>"..i18n("download").."&nbsp;<i class=\"fa fa-download fa-lg\"></i></th><td colspan=5>")
 
       local live_traffic_utils = require("live_traffic_utils")
       live_traffic_utils.printLiveTrafficForm(ifId)
 
       print("</td></tr>\n")
-      
+   end
+
+   if (isAdministrator() and ifstats.isView == false and ifstats.isDynamic == false) then      
       print("<tr><th width=250>"..i18n("if_stats_overview.reset_counters").."</th>")
       print("<td colspan=5>")
 
@@ -974,7 +980,7 @@ elseif(page == "trafficprofiles") then
      local statschart_icon = ''
 
      if ts_utils.exists("profile:traffic", {ifid=ifid}) then
-	 statschart_icon = '<A HREF=\"'..ntop.getHttpPrefix()..'/lua/profile_details.lua?profile='..trimmed..'\"><i class=\'fa fa-area-chart fa-lg\'></i></A>'
+	 statschart_icon = '<A HREF=\"'..ntop.getHttpPrefix()..'/lua/profile_details.lua?profile='..pname..'\"><i class=\'fa fa-area-chart fa-lg\'></i></A>'
      end
 
      print("<tr><th>"..pname.."</th><td align=center>"..statschart_icon.."</td><td><span id=profile_"..trimmed..">"..bytesToSize(pbytes).."</span> <span id=profile_"..trimmed.."_trend></span></td></tr>\n")
