@@ -173,7 +173,8 @@ void Host::initialize(Mac *_mac, u_int16_t _vlanId, bool init_all) {
   memset(&tcpPacketStats, 0, sizeof(tcpPacketStats));
   asn = 0, asname = NULL;
   as = NULL, country = NULL;
-  blacklisted_host = false, reloadHostBlacklist();
+  blacklisted_host = false;
+  reloadHostBlacklist();
 
   num_alerts_detected = 0;
   trigger_host_alerts = false;
@@ -1244,7 +1245,7 @@ void Host::reloadHostBlacklist() {
   char *ip_str = ip.print(ipbuf, sizeof(ipbuf));
   unsigned long category;
 
-  blacklisted_host = ((ndpi_get_custom_category_match(iface->get_ndpi_struct(), ip_str, &category) == 0) &&
+  blacklisted_host = ((ndpi_get_custom_category_match(iface->get_ndpi_struct(), ip_str, strlen(ip_str), &category) == 0) &&
     (category == CUSTOM_CATEGORY_MALWARE));
 }
 
