@@ -291,7 +291,7 @@ void Ntop::registerPrefs(Prefs *_prefs, bool quick_registration) {
 #endif
 
   /* License check could have increased the number of interfaces available */
-  initNetworkInterfaces();
+  resetNetworkInterfaces();
 
 #if defined(NTOPNG_PRO) && defined(HAVE_NINDEX)
 #if 0
@@ -342,7 +342,7 @@ void Ntop::registerNagios(void) {
 
 /* ******************************************* */
 
-void Ntop::initNetworkInterfaces() {
+void Ntop::resetNetworkInterfaces() {
   if(iface) delete []iface;
 
   if((iface = new NetworkInterface*[MAX_NUM_DEFINED_INTERFACES]) == NULL)
@@ -1196,10 +1196,10 @@ bool Ntop::checkUserPassword(const char * const user, const char * const passwor
         goto radius_auth_out;
       }
 
-#ifdef HAVE_RC_APPLY_CONFIG
+#ifdef HAVE_RC_TEST_CONFIG
       /* Necessary since radcli release 1.2.10 */
-      if(rc_apply_config(rh) != 0) {
-        ntop->getTrace()->traceEvent(TRACE_ERROR, "Radius: rc_apply_config failed");
+      if(rc_test_config(rh, "ntopng") != 0) {
+        ntop->getTrace()->traceEvent(TRACE_ERROR, "Radius: rc_test_config failed");
         goto radius_auth_out;
       }
 #endif
@@ -1979,16 +1979,14 @@ int Ntop::getInterfaceIdByName(lua_State *vm, const char * const name) {
 
 /* ****************************************** */
 
-void Ntop::registerInterface(NetworkInterface *_if) {
-  _if->finishInitialization(num_defined_interfaces);
-  _if->checkAggregationMode();
+bool Ntop::registerInterface(NetworkInterface *_if) {
 
   for(int i = 0; i < num_defined_interfaces; i++) {
     if(strcmp(iface[i]->get_name(), _if->get_name()) == 0) {
       ntop->getTrace()->traceEvent(TRACE_WARNING,
 				   "Skipping duplicated interface %s", _if->get_name());
       delete _if;
-      return;
+      return false;
     }
   }
 
@@ -1996,18 +1994,27 @@ void Ntop::registerInterface(NetworkInterface *_if) {
     ntop->getTrace()->traceEvent(TRACE_NORMAL, "Registered interface %s [id: %d]",
 				 _if->get_name(), _if->get_id());
     iface[num_defined_interfaces++] = _if;
-    _if->startDBLoop();
+    return true;
   } else {
     static bool too_many_interfaces_error = false;
     if(!too_many_interfaces_error) {
       ntop->getTrace()->traceEvent(TRACE_ERROR, "Too many interfaces defined");
       too_many_interfaces_error = true;
     }
+    return false;
   }
 };
 
 /* ******************************************* */
 
+void Ntop::initInterface(NetworkInterface *_if) {
+  _if->finishInitialization(num_defined_interfaces);
+  _if->checkAggregationMode();
+  _if->startDBLoop();
+}
+
+/* ******************************************* */
+
 void Ntop::sendNetworkInterfacesTermination() {
   for(int i=0; i<num_defined_interfaces; i++)
     iface[i]->sendTermination();
